@@ -203,11 +203,11 @@ class JSObject
     return hasFlag(js::ObjectFlag::GenerationCountedGlobal);
   }
 
-  bool hasFuseProperty() const {
-    return hasFlag(js::ObjectFlag::HasFuseProperty);
+  bool hasRealmFuseProperty() const {
+    return hasFlag(js::ObjectFlag::HasRealmFuseProperty);
   }
-  static bool setHasFuseProperty(JSContext* cx, JS::HandleObject obj) {
-    return setFlag(cx, obj, js::ObjectFlag::HasFuseProperty);
+  static bool setHasRealmFuseProperty(JSContext* cx, JS::HandleObject obj) {
+    return setFlag(cx, obj, js::ObjectFlag::HasRealmFuseProperty);
   }
 
   bool hasNonFunctionAccessor() const {
@@ -217,6 +217,8 @@ class JSObject
     return setFlag(cx, obj, js::ObjectFlag::HasNonFunctionAccessor);
   }
 
+  bool hasObjectFuse() const { return hasFlag(js::ObjectFlag::HasObjectFuse); }
+
   // A "qualified" varobj is the object on which "qualified" variable
   // declarations (i.e., those defined with "var") are kept.
   //
@@ -323,8 +325,6 @@ class JSObject
   /* Return the allocKind we would use if we were to tenure this object. */
   js::gc::AllocKind allocKindForTenure(const js::Nursery& nursery) const;
 
-  bool canHaveFixedElements() const;
-
   size_t tenuredSizeOfThis() const {
     MOZ_ASSERT(isTenured());
     return js::gc::Arena::thingSize(asTenured().getAllocKind());
@@ -338,7 +338,7 @@ class JSObject
   // can apply mallocSizeOf to bits and pieces of the object, whereas objects
   // in the nursery may have those bits and pieces allocated in the nursery
   // along with them, and are not each their own malloc blocks.
-  size_t sizeOfIncludingThisInNursery() const;
+  size_t sizeOfIncludingThisInNursery(mozilla::MallocSizeOf mallocSizeOf) const;
 
 #ifdef DEBUG
   static void debugCheckNewObject(js::Shape* shape, js::gc::AllocKind allocKind,
@@ -732,6 +732,10 @@ struct JSObject_Slots4 : JSObject {
   void* data[2];
   js::Value fslots[4];
 };
+struct JSObject_Slots6 : JSObject {
+  void* data[2];
+  js::Value fslots[6];
+};
 struct JSObject_Slots7 : JSObject {
   // Only used for extended functions which are required to have exactly seven
   // fixed slots due to JIT assumptions.
